pub struct GenericKeygenBuilder<'a, E: Curve, M, L: SecurityLevel, D: Digest> { /* private fields */ }Expand description
Key generation entry point with choice for threshold or non-threshold variant
Implementations
Sourceimpl<'a, E, L, D> GenericKeygenBuilder<'a, E, NonThreshold, L, D>where
E: Curve,
L: SecurityLevel,
D: Digest + Clone + 'static,
impl<'a, E, L, D> GenericKeygenBuilder<'a, E, NonThreshold, L, D>where
E: Curve,
L: SecurityLevel,
D: Digest + Clone + 'static,
Sourcepub fn new(eid: ExecutionId<'a>, i: u16, n: u16) -> Self
pub fn new(eid: ExecutionId<'a>, i: u16, n: u16) -> Self
Constructs KeygenBuilder
Takes local party index $i$ and number of parties $n$
Sourceimpl<'a, E, L, D, M> GenericKeygenBuilder<'a, E, M, L, D>where
E: Curve,
L: SecurityLevel,
D: Digest + Clone + 'static,
impl<'a, E, L, D, M> GenericKeygenBuilder<'a, E, M, L, D>where
E: Curve,
L: SecurityLevel,
D: Digest + Clone + 'static,
Sourcepub fn set_threshold(
self,
t: u16,
) -> GenericKeygenBuilder<'a, E, WithThreshold, L, D>
pub fn set_threshold( self, t: u16, ) -> GenericKeygenBuilder<'a, E, WithThreshold, L, D>
Specifies to generate key shares for a threshold scheme
Sourcepub fn set_digest<D2>(self) -> GenericKeygenBuilder<'a, E, M, L, D2>where
D2: Digest + Clone + 'static,
pub fn set_digest<D2>(self) -> GenericKeygenBuilder<'a, E, M, L, D2>where
D2: Digest + Clone + 'static,
Specifies another hash function to use
Sourcepub fn set_security_level<L2>(self) -> GenericKeygenBuilder<'a, E, M, L2, D>where
L2: SecurityLevel,
pub fn set_security_level<L2>(self) -> GenericKeygenBuilder<'a, E, M, L2, D>where
L2: SecurityLevel,
Specifies security level
Sourcepub fn set_progress_tracer(self, tracer: &'a mut dyn Tracer) -> Self
pub fn set_progress_tracer(self, tracer: &'a mut dyn Tracer) -> Self
Sets a tracer that tracks progress of protocol execution
Sourcepub fn enforce_reliable_broadcast(self, enforce: bool) -> Self
pub fn enforce_reliable_broadcast(self, enforce: bool) -> Self
Ensures reliability of broadcast channel by adding one extra communication round
CGGMP24 protocol requires message in the first round to be sent over reliable broadcast channel. We ensure reliability of the broadcast channel by introducing extra communication round (at cost of additional latency). You may disable it, for instance, if your transport layer is reliable by construction (e.g. you use blockchain for communications).
Default: true.
Sourceimpl<'a, E, L, D> GenericKeygenBuilder<'a, E, NonThreshold, L, D>where
E: Curve,
L: SecurityLevel,
D: Digest + Clone + 'static,
impl<'a, E, L, D> GenericKeygenBuilder<'a, E, NonThreshold, L, D>where
E: Curve,
L: SecurityLevel,
D: Digest + Clone + 'static,
Sourcepub async fn start<R, M>(
self,
rng: &mut R,
party: M,
) -> Result<CoreKeyShare<E>, KeygenError>
pub async fn start<R, M>( self, rng: &mut R, party: M, ) -> Result<CoreKeyShare<E>, KeygenError>
Starts key generation
Sourcepub fn into_state_machine<R>(
self,
rng: &'a mut R,
) -> impl StateMachine<Output = Result<CoreKeyShare<E>, KeygenError>, Msg = Msg<E, L, D>> + 'a
pub fn into_state_machine<R>( self, rng: &'a mut R, ) -> impl StateMachine<Output = Result<CoreKeyShare<E>, KeygenError>, Msg = Msg<E, L, D>> + 'a
Returns a state machine that can be used to carry out the key generation protocol
See [round_based::state_machine] for details on how that can be done.
Sourceimpl<'a, E, L, D> GenericKeygenBuilder<'a, E, WithThreshold, L, D>where
E: Curve,
L: SecurityLevel,
D: Digest + Clone + 'static,
impl<'a, E, L, D> GenericKeygenBuilder<'a, E, WithThreshold, L, D>where
E: Curve,
L: SecurityLevel,
D: Digest + Clone + 'static,
Sourcepub async fn start<R, M>(
self,
rng: &mut R,
party: M,
) -> Result<CoreKeyShare<E>, KeygenError>
pub async fn start<R, M>( self, rng: &mut R, party: M, ) -> Result<CoreKeyShare<E>, KeygenError>
Starts threshold key generation
Sourcepub fn into_state_machine<R>(
self,
rng: &'a mut R,
) -> impl StateMachine<Output = Result<CoreKeyShare<E>, KeygenError>, Msg = Msg<E, L, D>> + 'a
pub fn into_state_machine<R>( self, rng: &'a mut R, ) -> impl StateMachine<Output = Result<CoreKeyShare<E>, KeygenError>, Msg = Msg<E, L, D>> + 'a
Returns a state machine that can be used to carry out the key generation protocol
See [round_based::state_machine] for details on how that can be done.